checked_outputs_outcomes_count

Function checked_outputs_outcomes_count 

fn checked_outputs_outcomes_count(
    outpoint_range: OutPointRange,
) -> Result<usize>
Number of output outcomes outpoint_range asks for, if it is a range we are willing to serve.

The range is deserialized verbatim from an unauthenticated request, so it has to be bounded before anything is sized from it.