pub struct ConsensusApi {Show 18 fields
pub cfg: ServerConfig,
pub db: Database,
pub modules: ServerModuleRegistry,
pub client_cfg: ClientConfig,
pub force_api_secret: Option<String>,
pub submission_sender: Sender<ConsensusItem>,
pub shutdown_receiver: Receiver<Option<u64>>,
pub shutdown_sender: Sender<Option<u64>>,
pub ord_latency_receiver: Receiver<Option<Duration>>,
pub p2p_status_receivers: P2PStatusReceivers,
pub ci_status_receivers: BTreeMap<PeerId, Receiver<Option<u64>>>,
pub bitcoin_rpc_connection: ServerBitcoinRpcMonitor,
pub supported_api_versions: SupportedApiVersionsSummary,
pub auth_ui: Option<ApiAuth>,
pub auth_api: Option<ApiAuth>,
pub code_version_str: String,
pub code_version_hash: String,
pub task_group: TaskGroup,
}Fields
cfg: ServerConfigOur server configuration
db: DatabaseDatabase for serving the API
modules: ServerModuleRegistryModules registered with the federation
client_cfg: ClientConfigCached client config
force_api_secret: Option<String>submission_sender: Sender<ConsensusItem>For sending API events to consensus such as transactions
shutdown_receiver: Receiver<Option<u64>>shutdown_sender: Sender<Option<u64>>ord_latency_receiver: Receiver<Option<Duration>>p2p_status_receivers: P2PStatusReceiversci_status_receivers: BTreeMap<PeerId, Receiver<Option<u64>>>bitcoin_rpc_connection: ServerBitcoinRpcMonitorsupported_api_versions: SupportedApiVersionsSummaryauth_ui: Option<ApiAuth>auth_api: Option<ApiAuth>code_version_str: Stringcode_version_hash: Stringtask_group: TaskGroupImplementations
Sourceimpl ConsensusApi
impl ConsensusApi
pub fn api_versions_summary(&self) -> &SupportedApiVersionsSummary
pub fn get_active_api_secret(&self) -> Option<String>
pub async fn submit_transaction( &self, transaction: Transaction, ) -> Result<TransactionId, TransactionError>
pub async fn await_transaction( &self, txid: TransactionId, ) -> (Vec<ModuleInstanceId>, DatabaseTransaction<'_, Committable>)
pub async fn await_output_outcome( &self, outpoint: OutPoint, ) -> Result<SerdeModuleEncoding<DynOutputOutcome>>
pub async fn await_outputs_outcomes( &self, outpoint_range: OutPointRange, ) -> Result<Vec<Option<SerdeModuleEncoding<DynOutputOutcome>>>>
pub async fn session_count(&self) -> u64
pub async fn await_signed_session_outcome( &self, index: u64, ) -> SignedSessionOutcome
pub async fn session_status(&self, session_index: u64) -> SessionStatusV2
pub async fn get_federation_status(&self) -> ApiResult<LegacyFederationStatus>
fn shutdown(&self, index: Option<u64>)
async fn get_federation_audit(&self) -> ApiResult<AuditSummary>
Sourcefn get_guardian_config_backup(
&self,
_auth: &GuardianAuthToken,
) -> GuardianConfigBackup
fn get_guardian_config_backup( &self, _auth: &GuardianAuthToken, ) -> GuardianConfigBackup
Uses the in-memory config to write a config backup tar archive that guardians can download. Private keys are stored as plaintext JSON. Operators should rely on disk encryption for at-rest protection.
async fn handle_backup_request( &self, dbtx: &mut DatabaseTransaction<'_>, request: SignedBackupRequest, ) -> Result<(), ApiError>
async fn handle_recover_request( &self, dbtx: &mut DatabaseTransaction<'_>, id: PublicKey, ) -> Option<ClientBackupSnapshot>
Sourceasync fn api_announcements(&self) -> BTreeMap<PeerId, SignedApiAnnouncement>
async fn api_announcements(&self) -> BTreeMap<PeerId, SignedApiAnnouncement>
List API URL announcements from all peers we have received them from (at least ourselves)
Sourcefn fedimintd_version(&self) -> String
fn fedimintd_version(&self) -> String
Returns the tagged fedimintd version currently running
Sourceasync fn submit_api_announcement(
&self,
peer_id: PeerId,
announcement: SignedApiAnnouncement,
) -> Result<(), ApiError>
async fn submit_api_announcement( &self, peer_id: PeerId, announcement: SignedApiAnnouncement, ) -> Result<(), ApiError>
Add an API URL announcement from a peer to our database to be returned
by ConsensusApi::api_announcements.
async fn sign_api_announcement(&self, new_url: SafeUrl) -> SignedApiAnnouncement
async fn guardian_metadata_list( &self, ) -> BTreeMap<PeerId, SignedGuardianMetadata>
async fn submit_guardian_metadata( &self, peer_id: PeerId, metadata: SignedGuardianMetadata, ) -> Result<(), ApiError>
async fn sign_guardian_metadata( &self, new_metadata: GuardianMetadata, ) -> SignedGuardianMetadata
async fn get_invite_code(&self, api_secret: Option<String>) -> InviteCode